@@ -8,7 +8,7 @@ from flatbuffers.builder import np
 from sklearn.datasets import fetch_20newsgroups, fetch_openml
 
 from chester.run.full_run import run_madcat
-from chester.run.user_classes import Data, ModelRun, TimeSeriesHandler, TextFeatureExtraction
+from chester.run.user_classes import Data, ModelRun, TimeSeriesHandler, TextFeatureExtraction, TextSummary
 import yfinance as yf
 import ml_datasets
 
@@ -16,21 +16,19 @@ import ml_datasets
 target_column = 'target'
 import matplotlib.pyplot as plt
 
-
 # Disable interactive mode
 # plt.ioff()
 
 
 ################################################################################################
-# df1 = load_data_pirates().assign(target='pirate').sample(300, replace=True)
-# df2 = load_data_king_arthur().assign(target='arthur').sample(300, replace=True)
-# df3 = load_data_chat_logs().assign(target='chat').sample(300, replace=True)
-# df = pd.concat([
-#     df1, df2,
-#     df3
-# ])
-
-
+df1 = load_data_pirates().assign(target='pirate').sample(300, replace=True)
+df2 = load_data_king_arthur().assign(target='arthur').sample(300, replace=True)
+df3 = load_data_chat_logs().assign(target='chat').sample(300, replace=True)
+df = pd.concat([
+    df1, df2,
+    df3
+])
+#
 # df['target'] = df['target'].apply(lambda x: 0 if "pirate" in x else 1)  # can do with or without
 ################################################################################################
 
@@ -56,12 +54,22 @@ import matplotlib.pyplot as plt
 # df.rename(columns={'cnt': 'target'}, inplace=True)
 ###############################################################################################
 
+
 ###############################################################################################
 # df = pd.read_csv("/Users/amitosi/PycharmProjects/chester/chester/data/camps.csv")
 # df.rename(columns={'Competitors ': 'target'}, inplace=True)
 ###############################################################################################
 
 
+###############################################################################################
+# df = pd.read_csv("/Users/amitosi/PycharmProjects/chester/chester/data/Reviews.csv")
+# df = df[['Text', 'Summary', 'ProductId']]
+
+
+# df = df[['Text', 'Summary']]
+###############################################################################################
+
+
 ###############################################################################################
 # df = pd.read_csv("/Users/amitosi/PycharmProjects/chester/chester/data/daily_cinema.csv")
 # df.rename(columns={'humidity': 'target'}, inplace=True)
@@ -418,9 +426,21 @@ def load_dataset(name):
 # df = load_dataset('abalone')
 # df = load_dataset('kropt')
 # df = load_dataset('yokohoma2')
-df = load_dataset('cpu_small')
+# df = load_dataset('cpu_small')
 
-madcat_collector = run_madcat(Data(df=df, target_column='target'), model_run=ModelRun(n_models=2))
+# top_10 = df['ProductId'].value_counts().nlargest(10).index
+# filtered_df = df[df['ProductId'].isin(top_10)]
+
+
+chester_collector = run_madcat(Data(df=df),
+                               is_feature_stats=True,
+                               is_pre_model=True,
+                               text_summary=TextSummary(summary_num_sentences=3, max_terms=5),
+                               # feature_types={'numeric': [], 'boolean': [], 'text': ['Text', 'Summary'],
+                               #                'categorical': [], 'time': [], 'id': ['ProductId']}
+                               # text_summary=TextSummary(summary_num_sentences=3, max_terms=20),
+                               # model_run=ModelRun(n_models=1),
+                               )
 # madcat_collector = run_madcat(Data(df=df, target_column='target'),
 #                               is_feature_stats=True,
 #                               # text_feature_extraction=TextFeatureExtraction(corex_dim=2, anchor_words=anchors),
