@@ -26,6 +26,8 @@ def is_date(string):
 
     # Check if the string matches any of the known formats or regexes
     try:
+        if string.isdigit() and len(string) >= 9:
+            return False
         parse(string)
         return True
     except ValueError:
