@@ -8,7 +8,6 @@ from torchvision import models
 from tqdm import tqdm
 
 from diamond.user_classes import ImagesData, ImageModel
-import os
 
 
 class ImageModelTraining:
@@ -30,18 +29,29 @@ class ImageModelTraining:
         self.is_colored = self.images_data.is_colored
 
     def get_model(self):
-        BASE_DIR = os.getcwd()
-        MODEL_DIR = os.path.join(BASE_DIR,  "model_training", "saved_models")
-        print("wow!\n", MODEL_DIR)
         supported_models = ["EfficientNetB0", "EfficientNetB4", "EfficientNetB7", "ResNet50", "ResNet101",
                             "DenseNet121", "DenseNet161", "DenseNet201"]
-        if self.image_model.network_name not in supported_models:
+        if self.image_model.network_name == "EfficientNetB0":
+            model = hub.load('rwightman/pytorch-image-models', 'efficientnet_b0', pretrained=True)
+        elif self.image_model.network_name == "EfficientNetB4":
+            model = hub.load('rwightman/pytorch-image-models', 'efficientnet_b4', pretrained=True)
+        elif self.image_model.network_name == "EfficientNetB7":
+            model = hub.load('rwightman/pytorch-image-models', 'efficientnet_b7', pretrained=True)
+        elif self.image_model.network_name == "ResNet50":
+            model = models.resnet50(pretrained=True)
+        elif self.image_model.network_name == "ResNet101":
+            model = models.resnet101(pretrained=True)
+        elif self.image_model.network_name == "DenseNet121":
+            model = models.densenet121(pretrained=True)
+        elif self.image_model.network_name == "DenseNet161":
+            model = models.densenet161(pretrained=True)
+        elif self.image_model.network_name == "DenseNet169":
+            model = models.densenet169(pretrained=True)
+        elif self.image_model.network_name == "DenseNet201":
+            model = models.densenet201(pretrained=True)
+        else:
             raise ValueError(
                 f"Unsupported network name: {self.image_model.network_name}, please choose one of: {supported_models}")
-        model_path = os.path.join(MODEL_DIR, f"{self.image_model.network_name}.pt")
-        if not os.path.exists(model_path):
-            raise ValueError(f"No saved model found for {self.image_model.network_name}, please save the model first")
-        model = torch.load(model_path, map_location=self.device)
         return model
 
     def load_model(self):
@@ -172,4 +182,4 @@ class ImageModelTraining:
         optimizer = optim.Adam(model.parameters(), **optimizer_params)  # get rid of lr
         train_loss, val_loss = self.train_model(model, criterion, optimizer)  # get rid of epochs
         self.evaluate_predictions = self.get_eval_prediction(model, self.val_loader, device=self.device)
-        return model, train_loss, val_loss, self.evaluate_predictions
+        return model, train_loss, val_loss, self.evaluate_predictions
\ No newline at end of file
